"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IconThemeStore = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const common_1 = require("../common");
const icon_theme_data_1 = require("./icon-theme-data");
let IconThemeStore = class IconThemeStore {
    constructor() {
        this.iconThemeMap = new Map();
    }
    async getIconTheme(contribution, basePath) {
        if (!contribution || !basePath) {
            return;
        }
        const id = (0, common_1.getThemeId)(contribution);
        const cachedTheme = this.iconThemeMap.get(id);
        if (cachedTheme) {
            return cachedTheme;
        }
        const iconTheme = await this.initIconTheme(contribution, basePath);
        this.iconThemeMap.set(id, iconTheme);
        return iconTheme;
    }
    async initIconTheme(contribution, basePath) {
        const contributedPath = contribution.path.replace(/^\.\//, '');
        // http 的不作支持
        const themeLocation = basePath.resolve(contributedPath);
        const iconThemeData = this.injector.get(icon_theme_data_1.IconThemeData);
        await iconThemeData.load(themeLocation);
        return iconThemeData;
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(di_1.INJECTOR_TOKEN),
    tslib_1.__metadata("design:type", di_1.Injector)
], IconThemeStore.prototype, "injector", void 0);
IconThemeStore = tslib_1.__decorate([
    (0, di_1.Injectable)()
], IconThemeStore);
exports.IconThemeStore = IconThemeStore;
//# sourceMappingURL=icon-theme-store.js.map