"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProductIconThemeStore = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const common_1 = require("../common");
const product_icon_theme_data_1 = require("./product-icon-theme-data");
let ProductIconThemeStore = class ProductIconThemeStore {
    constructor() {
        this.productIconThemeMap = new Map();
    }
    async getProductIconTheme(contribution, basePath) {
        if (!contribution || !basePath) {
            return;
        }
        const id = (0, common_1.getThemeId)(contribution);
        const cachedTheme = this.productIconThemeMap.get(id);
        if (cachedTheme) {
            return cachedTheme;
        }
        const iconTheme = await this.initProductIconTheme(contribution, basePath);
        this.productIconThemeMap.set(id, iconTheme);
        return iconTheme;
    }
    async initProductIconTheme(contribution, basePath) {
        const contributedPath = contribution.path.replace(/^\.\//, '');
        const themeLocation = basePath.resolve(contributedPath);
        const iconThemeData = this.injector.get(product_icon_theme_data_1.ProductIconThemeData, [
            contribution.id,
            contribution.label,
            contribution.extensionId,
        ]);
        await iconThemeData.load(themeLocation);
        return iconThemeData;
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(di_1.INJECTOR_TOKEN),
    tslib_1.__metadata("design:type", di_1.Injector)
], ProductIconThemeStore.prototype, "injector", void 0);
ProductIconThemeStore = tslib_1.__decorate([
    (0, di_1.Injectable)()
], ProductIconThemeStore);
exports.ProductIconThemeStore = ProductIconThemeStore;
//# sourceMappingURL=product-icon-theme-store.js.map