"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnthemedProductIconTheme = exports.getIconsStyleSheet = exports.ProductIconService = exports.asCSSPropertyValue = exports.asCSSUrl = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const common_1 = require("../common");
const icon_registry_1 = require("../common/icon-registry");
const product_icon_theme_data_1 = require("./product-icon-theme-data");
const product_icon_theme_store_1 = require("./product-icon-theme-store");
function asCSSUrl(uri, staticResourceService) {
    if (!uri) {
        return 'url("")';
    }
    function resolvePath(uri) {
        if (uri.scheme === 'https') {
            return uri.toString();
        }
        // file 协议的需要走 static-resource
        return staticResourceService.resolveStaticResource(uri);
    }
    return `url('${resolvePath(uri).toString(true).replace(/'/g, '%27')}')`;
}
exports.asCSSUrl = asCSSUrl;
function asCSSPropertyValue(value) {
    return `'${value.replace(/'/g, '%27')}'`;
}
exports.asCSSPropertyValue = asCSSPropertyValue;
let ProductIconService = class ProductIconService extends ide_core_browser_1.WithEventBus {
    constructor() {
        super();
        this.themeChangeEmitter = new ide_core_browser_1.Emitter();
        this.productIconThemeLoaded = new ide_core_browser_1.Deferred();
        this.productIconContributionRegistry = new Map();
        this.onDidProductIconThemeChange = this.themeChangeEmitter.event;
        this.defaultProductIconThemeData = new product_icon_theme_data_1.ProductIconThemeData(common_1.DEFAULT_PRODUCT_ICON_THEME_ID, common_1.DEFAULT_PRODUCT_ICON_THEME_LABEL, common_1.DEFAULT_PRODUCT_ICON_THEME_ID);
        this.listen();
        this.getIconsStyleSheet = getIconsStyleSheet(this, this.staticResourceService);
        this.disposables.push(this.getIconsStyleSheet);
        this.productIconContributionRegistry.set(common_1.DEFAULT_PRODUCT_ICON_THEME_ID, {
            contribution: {
                id: this.defaultProductIconThemeData.id,
                label: this.defaultProductIconThemeData.label,
                path: '',
                extensionId: this.defaultProductIconThemeData.id,
            },
        });
    }
    listen() {
        this.preferenceService.onPreferenceChanged(async (e) => {
            if (e.preferenceName === "general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */ &&
                this.productIconContributionRegistry.has(e.newValue)) {
                await this.applyTheme(this.preferenceService.get("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */));
            }
        });
    }
    async onDidExtensionContributes() {
        await this.updateProductIconThemes();
    }
    get preferenceThemeId() {
        return this.preferenceService.get("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */);
    }
    get currentThemeData() {
        return this.currentTheme;
    }
    /**
     * 初始化注册默认主题
     */
    async updateProductIconThemes() {
        const themeMap = this.getAvailableThemeInfos().reduce((pre, cur) => {
            if (!pre.has(cur.themeId)) {
                pre.set(cur.themeId, cur.name);
            }
            return pre;
        }, new Map());
        this.preferenceSettings.setEnumLabels("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */, Object.fromEntries(themeMap.entries()));
        // 当前没有主题，或没有缓存的主题时，将第一个注册主题设置为当前主题
        if (!this.currentTheme) {
            if (!this.preferenceThemeId || !themeMap.has(this.preferenceThemeId)) {
                const themeId = Array.from(themeMap.keys())[0];
                if (themeId) {
                    await this.applyTheme(themeId);
                }
            }
            else {
                await this.applyTheme(this.preferenceThemeId);
            }
        }
        this.productIconThemeLoaded.resolve();
    }
    async applyTheme(themeId) {
        if (this.currentTheme && this.currentThemeId === themeId) {
            return;
        }
        this.latestApplyTheme = themeId;
        const productIconThemeData = await this.getProductIconTheme(themeId);
        if (this.latestApplyTheme !== themeId) {
            return;
        }
        let sumiIconStyleNode = document.getElementById(common_1.PRODUCT_ICON_STYLE_ID);
        let codIconStyleNode = document.getElementById(common_1.PRODUCT_ICON_CODICON_STYLE_ID);
        this.currentThemeId = themeId;
        if (!productIconThemeData) {
            this.currentTheme = this.defaultProductIconThemeData;
        }
        else {
            this.currentTheme = productIconThemeData;
        }
        /**
         * product-icon-style 内存储 opensumi icon
         * codiconStyles 内存储 codicon icon
         * monaco-colors 内为 monaco 内置样式
         * 注册时序为 monaco-colors -> codiconStyles -> product-icon-style
         * TODO 此处 monaco-colors 的注册时序无法保证
         */
        const codiconStyles = this.getIconsStyleSheet.getCSS();
        const sumiiconStyles = this.getIconsStyleSheet.getSumiCSS();
        if (codIconStyleNode) {
            codIconStyleNode.innerHTML = codiconStyles || '';
        }
        else {
            codIconStyleNode = document.createElement('style');
            codIconStyleNode.id = common_1.PRODUCT_ICON_CODICON_STYLE_ID;
            codIconStyleNode.innerHTML = codiconStyles || '';
            document.getElementsByTagName('head')[0].appendChild(codIconStyleNode);
        }
        if (sumiIconStyleNode) {
            sumiIconStyleNode.innerHTML = sumiiconStyles || '';
        }
        else {
            sumiIconStyleNode = document.createElement('style');
            sumiIconStyleNode.id = common_1.PRODUCT_ICON_STYLE_ID;
            sumiIconStyleNode.innerHTML = sumiiconStyles || '';
            document.getElementsByTagName('head')[0].appendChild(sumiIconStyleNode);
        }
        this.themeChangeEmitter.fire(this.currentTheme);
        if (!this.preferenceThemeId) {
            this.productIconThemeLoaded.resolve();
        }
    }
    async getProductIconTheme(themeId) {
        let theme;
        const extContribution = this.productIconContributionRegistry.get(themeId);
        if (extContribution) {
            theme = await this.productIconThemeStore.getProductIconTheme(extContribution.contribution, extContribution.basePath);
            return theme;
        }
        return;
    }
    registerProductIconThemes(productIconThemesContribution, basePath) {
        const preferencesProductIcon = this.preferenceService.get("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */);
        for (const contribution of productIconThemesContribution) {
            const themeId = (0, common_1.getThemeId)(contribution);
            this.productIconContributionRegistry.set(themeId, { contribution, basePath });
            if (preferencesProductIcon && preferencesProductIcon === themeId) {
                this.applyTheme(preferencesProductIcon);
            }
        }
        const currentSchemas = this.preferenceSchemaProvider.getPreferenceProperty("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */);
        if (currentSchemas) {
            delete currentSchemas.scope;
        }
        this.preferenceSchemaProvider.setSchema({
            properties: {
                ["general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */]: Object.assign(Object.assign({}, currentSchemas), { enum: this.getAvailableThemeInfos().map((info) => info.themeId) }),
            },
        }, true);
        const themeMap = this.getAvailableThemeInfos().reduce((pre, cur) => {
            if (!pre.has(cur.themeId)) {
                pre.set(cur.themeId, cur.name);
            }
            return pre;
        }, new Map());
        this.preferenceSettings.setEnumLabels("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */, Object.fromEntries(themeMap.entries()));
        // 当前没有主题，或没有缓存的主题时，将第一个注册主题设置为当前主题
        if (!this.currentThemeId && themeMap.size <= 1) {
            if (!preferencesProductIcon || !themeMap.has(preferencesProductIcon)) {
                const themeId = Array.from(themeMap.keys())[0];
                if (themeId) {
                    this.applyTheme(themeId);
                }
            }
        }
    }
    getAvailableThemeInfos() {
        const themeInfos = [];
        for (const { contribution } of this.productIconContributionRegistry.values()) {
            const { label, id, extensionId } = contribution;
            themeInfos.push({
                themeId: id || (0, common_1.getThemeId)(contribution),
                name: label,
                extensionId,
            });
        }
        return themeInfos;
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(),
    tslib_1.__metadata("design:type", ide_core_browser_1.StaticResourceService)
], ProductIconService.prototype, "staticResourceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(),
    tslib_1.__metadata("design:type", product_icon_theme_store_1.ProductIconThemeStore)
], ProductIconService.prototype, "productIconThemeStore", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.PreferenceService),
    tslib_1.__metadata("design:type", Object)
], ProductIconService.prototype, "preferenceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.PreferenceSchemaProvider),
    tslib_1.__metadata("design:type", ide_core_browser_1.PreferenceSchemaProvider)
], ProductIconService.prototype, "preferenceSchemaProvider", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.IPreferenceSettingsService),
    tslib_1.__metadata("design:type", Object)
], ProductIconService.prototype, "preferenceSettings", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.ILogger),
    tslib_1.__metadata("design:type", Object)
], ProductIconService.prototype, "logger", void 0);
tslib_1.__decorate([
    (0, ide_core_browser_1.OnEvent)(ide_core_browser_1.ExtensionDidContributes),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Promise)
], ProductIconService.prototype, "onDidExtensionContributes", null);
ProductIconService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], ProductIconService);
exports.ProductIconService = ProductIconService;
function getIconsStyleSheet(themeService, staticResourceService) {
    const disposable = new ide_core_browser_1.DisposableStore();
    const onDidChangeEmmiter = disposable.add(new ide_core_browser_1.Emitter());
    const iconRegistry = (0, icon_registry_1.getIconRegistry)();
    disposable.add(iconRegistry.onDidChange(() => onDidChangeEmmiter.fire()));
    if (themeService) {
        disposable.add(themeService.onDidProductIconThemeChange(() => onDidChangeEmmiter.fire()));
    }
    return {
        dispose: () => disposable.dispose(),
        onDidChange: onDidChangeEmmiter.event,
        getCSS() {
            const productIconTheme = themeService ? themeService.currentThemeData : new UnthemedProductIconTheme();
            const usedFontIds = {};
            const formatIconRule = (contribution) => {
                const definition = productIconTheme.getIcon(contribution);
                if (!definition) {
                    return undefined;
                }
                const fontContribution = definition.font;
                if (fontContribution) {
                    usedFontIds[fontContribution.id] = fontContribution.definition;
                    return `.codicon-${contribution.id}:before { content: '${definition.fontCharacter}'; font-family: ${asCSSPropertyValue(fontContribution.id)}; }`;
                }
                return `.codicon-${contribution.id}:before { content: '${definition.fontCharacter}'; }`;
            };
            const rules = [];
            for (const contribution of iconRegistry.getIcons()) {
                const rule = formatIconRule(contribution);
                if (rule) {
                    rules.push(rule);
                }
            }
            for (const id in usedFontIds) {
                if (Object.hasOwn(usedFontIds, id)) {
                    const definition = usedFontIds[id];
                    const fontWeight = definition.weight ? `font-weight: ${definition.weight};` : '';
                    const fontStyle = definition.style ? `font-style: ${definition.style};` : '';
                    const src = definition.src
                        .map((l) => `${asCSSUrl(l.location, staticResourceService)} format('${l.format}')`)
                        .join(', ');
                    rules.push(`@font-face { src: ${src}; font-family: ${asCSSPropertyValue(id)};${fontWeight}${fontStyle} font-display: block; }`);
                }
            }
            return rules.join('\n');
        },
        getSumiCSS() {
            const productIconTheme = themeService ? themeService.currentThemeData : new UnthemedProductIconTheme();
            const usedFontIds = {};
            const formatIconRule = (contribution) => {
                const definition = productIconTheme.getIcon(contribution);
                if (!definition) {
                    return undefined;
                }
                const fontContribution = definition.font;
                if (fontContribution) {
                    usedFontIds[fontContribution.id] = fontContribution.definition;
                    // slice for 'sumi-' prefix
                    return `.kticon-${contribution.id.slice(5)}:before { content: '${definition.fontCharacter}'; font-family: ${asCSSPropertyValue(fontContribution.id)}; }`;
                }
                return `.kticon-${contribution.id.slice(5)}:before { content: '${definition.fontCharacter}'; }`;
            };
            const rules = [];
            // get sumi icons
            for (const contribution of iconRegistry.getIcons(true)) {
                const rule = formatIconRule(contribution);
                if (rule) {
                    rules.push(rule);
                }
            }
            for (const id in usedFontIds) {
                if (Object.hasOwn(usedFontIds, id)) {
                    const definition = usedFontIds[id];
                    const fontWeight = definition.weight ? `font-weight: ${definition.weight};` : '';
                    const fontStyle = definition.style ? `font-style: ${definition.style};` : '';
                    const src = definition.src
                        .map((l) => `${asCSSUrl(l.location, staticResourceService)} format('${l.format}')`)
                        .join(', ');
                    rules.push(`@font-face { src: ${src}; font-family: ${asCSSPropertyValue(id)};${fontWeight}${fontStyle} font-display: block; }`);
                }
            }
            return rules.join('\n');
        },
    };
}
exports.getIconsStyleSheet = getIconsStyleSheet;
class UnthemedProductIconTheme {
    getIcon(contribution) {
        const iconRegistry = (0, icon_registry_1.getIconRegistry)();
        let definition = contribution.defaults;
        while (ide_core_browser_1.ThemeIcon.isThemeIcon(definition)) {
            const c = iconRegistry.getIcon(definition.id);
            if (!c) {
                return undefined;
            }
            definition = c.defaults;
        }
        return definition;
    }
}
exports.UnthemedProductIconTheme = UnthemedProductIconTheme;
//# sourceMappingURL=product-icon.service.js.map