"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CSSStyleService = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
let CSSStyleService = class CSSStyleService {
    constructor() {
        const style = document.createElement('style');
        document.body.appendChild(style);
        this.styleSheet = style.sheet;
    }
    addClass(classname, style) {
        const ruleContent = [`.${classname} {`, createStyleCssText(style), '}'].join(' ');
        this.styleSheet.insertRule(ruleContent);
        return {
            dispose: () => {
                this.removeClass(classname);
            },
        };
    }
    removeClass(classname) {
        for (let i = this.styleSheet.rules.length - 1; i >= 0; i--) {
            if (this.styleSheet.rules[i].selectorText === '.' + classname) {
                this.styleSheet.removeRule(i);
            }
        }
    }
};
CSSStyleService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], CSSStyleService);
exports.CSSStyleService = CSSStyleService;
function createStyleCssText(styles) {
    const texts = [];
    Object.keys(styles).forEach((key) => {
        if (styles[key]) {
            texts.push(toDashSplitForm(key) + ':' + styles[key]);
        }
    });
    return texts.join(';');
}
function toDashSplitForm(key) {
    return key
        .trim()
        .split(/(?=[A-Z])/)
        .join('-')
        .toLowerCase();
}
//# sourceMappingURL=style.service.js.map