import { IRawThemeSetting } from 'vscode-textmate';
import { URI } from '@opensumi/ide-core-browser';
import { Color } from '../common/color';
import { ISemanticTokenRegistry, ProbeScope, TextMateThemingRuleDefinitions, TokenStyle, TokenStyleDefinitions, TokenStyleValue } from '../common/semantic-tokens-registry';
import { BuiltinTheme, ColorScheme, IColorMap, IColors, IThemeData, ITokenColorizationRule, ITokenThemeRule } from '../common/theme.service';
export declare class ThemeData implements IThemeData {
    id: string;
    name: string;
    themeSettings: IRawThemeSetting[];
    colors: IColors;
    encodedTokensColors: string[];
    rules: ITokenThemeRule[];
    base: BuiltinTheme;
    inherit: boolean;
    colorMap: IColorMap;
    private hasDefaultTokens;
    private customSettings;
    private semanticHighlighting?;
    private themeTokenScopeMatchers;
    private tokenColorIndex;
    private semanticTokenRules;
    private fileServiceClient;
    private readonly logger;
    private reporter;
    protected readonly semanticTokenRegistry: ISemanticTokenRegistry;
    initializeFromData(data: any): void;
    get type(): ColorScheme;
    getDefaultTheme(): any;
    initializeThemeData(id: string, name: string, base: string, themeLocation: URI): Promise<void>;
    loadCustomTokens(customSettings: ITokenColorizationRule[]): void;
    get settings(): IRawThemeSetting[];
    get tokenColors(): IRawThemeSetting[];
    protected doInitTokenRules(): void;
    private safeParseJSON;
    private readSemanticTokenRule;
    private loadColorTheme;
    private loadSyntaxTokens;
    protected transform(tokenColor: ITokenColorizationRule, acceptor: (rule: ITokenThemeRule) => void): void;
    getTokenColorIndex(): TokenColorIndex;
    getTokenStyle(type: string, modifiers: string[], language: string, useDefault?: boolean, definitions?: TokenStyleDefinitions): TokenStyle | undefined;
    /**
     * @param tokenStyleValue Resolve a tokenStyleValue in the context of a theme
     */
    resolveTokenStyleValue(tokenStyleValue: TokenStyleValue | undefined): TokenStyle | undefined;
    resolveScopes(scopes: ProbeScope[], definitions?: TextMateThemingRuleDefinitions): TokenStyle | undefined;
}
declare class TokenColorIndex {
    private _lastColorId;
    private _id2color;
    private _color2id;
    constructor();
    add(color: string | Color | undefined): number;
    get(color: string | Color | undefined): number;
    asArray(): string[];
}
export {};
//# sourceMappingURL=theme-data.d.ts.map