"use strict";
var ThemeStore_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemeStore = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const theme_service_1 = require("../common/theme.service");
let ThemeStore = ThemeStore_1 = class ThemeStore {
    constructor() {
        this.themes = {};
    }
    async initTheme(contribution, extPath) {
        const themePath = contribution.path.replace(/^\.\//, '');
        const themeLocation = extPath.resolve(themePath);
        const themeName = contribution.label;
        const themeId = (0, theme_service_1.getThemeId)(contribution);
        const themeBase = contribution.uiTheme || 'vs-dark';
        await this.initThemeData(themeId, themeName, themeBase, themeLocation);
        return this.themes[themeId];
    }
    async initThemeData(id, themeName, themeBase, themeLocation) {
        let themeData = this.getTheme(id);
        if (!themeData) {
            themeData = this.injector.get(theme_service_1.IThemeData);
            await themeData.initializeThemeData(id, themeName, themeBase, themeLocation);
            this.themes[id] = themeData;
        }
    }
    loadDefaultTheme() {
        (0, ide_core_common_1.getDebugLogger)().warn('The default theme extension is not detected, and the default theme style is used.');
        const theme = this.injector.get(theme_service_1.IThemeData);
        theme.initializeFromData(theme.getDefaultTheme());
        return theme;
    }
    async tryLoadLatestTheme() {
        // 尝试使用最近一次缓存的主题信息进行加载
        const themeData = this.getLatestThemeData();
        if (themeData) {
            try {
                const { contribution, basePath } = themeData;
                const theme = await this.initTheme(contribution, new ide_core_common_1.URI(basePath));
                return theme;
            }
            catch (e) {
                // 主题不存在或被卸载时，移除缓存，使用默认样式
                localStorage.removeItem(ThemeStore_1.STORE_THEME_DATA_KEY);
            }
        }
        return this.loadDefaultTheme();
    }
    storeLatestThemeData(contribution, basePath) {
        localStorage.setItem(ThemeStore_1.STORE_THEME_DATA_KEY, JSON.stringify({ contribution, basePath: basePath === null || basePath === void 0 ? void 0 : basePath.toString() }));
    }
    getLatestThemeData() {
        const data = localStorage.getItem(ThemeStore_1.STORE_THEME_DATA_KEY);
        if (data) {
            return JSON.parse(data);
        }
    }
    getTheme(id) {
        return this.themes[id];
    }
    async getThemeData(contribution, basePath) {
        // 测试情况下传入的contribution为空，尝试加载上次缓存的最新主题
        if (!contribution || !basePath) {
            return await this.tryLoadLatestTheme();
        }
        const id = (0, theme_service_1.getThemeId)(contribution);
        if (!this.getTheme(id)) {
            const theme = await this.initTheme(contribution, basePath);
            if (theme) {
                // 正常加载主题
                this.storeLatestThemeData(contribution, basePath);
                return theme;
            }
            // 加载主题出现了未知问题, 使用默认主题配色
            return this.loadDefaultTheme();
        }
        // 主题有缓存
        return this.getTheme(id);
    }
};
ThemeStore.STORE_THEME_DATA_KEY = 'latestTheme';
tslib_1.__decorate([
    (0, di_1.Autowired)(di_1.INJECTOR_TOKEN),
    tslib_1.__metadata("design:type", di_1.Injector)
], ThemeStore.prototype, "injector", void 0);
ThemeStore = ThemeStore_1 = tslib_1.__decorate([
    (0, di_1.Injectable)()
], ThemeStore);
exports.ThemeStore = ThemeStore;
//# sourceMappingURL=theme-store.js.map