"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemeContribution = exports.PRODUCT_ICON_THEME_TOGGLE_COMMAND = exports.ICON_THEME_TOGGLE_COMMAND = exports.THEME_TOGGLE_COMMAND = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const common_1 = require("../common");
const semantic_tokens_registry_1 = require("../common/semantic-tokens-registry");
exports.THEME_TOGGLE_COMMAND = {
    id: 'theme.toggle',
    label: '%theme.toggle%',
};
exports.ICON_THEME_TOGGLE_COMMAND = {
    id: 'theme.icon.toggle',
    label: '%theme.icon.toggle%',
};
exports.PRODUCT_ICON_THEME_TOGGLE_COMMAND = {
    id: 'theme.productIcon.toggle',
    label: '%theme.productIcon.toggle%',
};
let ThemeContribution = class ThemeContribution {
    async initialize() {
        this.registerDefaultColorTheme();
        this.registerDefaultTokenStyles();
        this.registerDefaultTokenType();
        this.registerDefaultTokenModifier();
        await this.themeService.colorThemeLoaded.promise;
    }
    /**
     * 如果没有设置默认 theme 或者 设置的 theme 为 dark 类型，为了有体感上的加速，设置默认的 theme
     */
    registerDefaultColorTheme() {
        const themeId = this.preferenceService.get("general.theme" /* GeneralSettingsId.Theme */);
        const shouldApplyDefaultThemeId = !themeId || themeId.includes('dark');
        if (shouldApplyDefaultThemeId) {
            this.themeService.applyTheme(common_1.DEFAULT_THEME_ID);
        }
    }
    registerDefaultTokenModifier() {
        this.semanticTokenRegistry.registerTokenModifier('declaration', (0, ide_core_browser_1.localize)('declaration', 'Style for all symbol declarations.'), undefined);
        this.semanticTokenRegistry.registerTokenModifier('documentation', (0, ide_core_browser_1.localize)('documentation', 'Style to use for references in documentation.'), undefined);
        this.semanticTokenRegistry.registerTokenModifier('static', (0, ide_core_browser_1.localize)('static', 'Style to use for symbols that are static.'), undefined);
        this.semanticTokenRegistry.registerTokenModifier('abstract', (0, ide_core_browser_1.localize)('abstract', 'Style to use for symbols that are abstract.'), undefined);
        this.semanticTokenRegistry.registerTokenModifier('deprecated', (0, ide_core_browser_1.localize)('deprecated', 'Style to use for symbols that are deprecated.'), undefined);
        this.semanticTokenRegistry.registerTokenModifier('modification', (0, ide_core_browser_1.localize)('modification', 'Style to use for write accesses.'), undefined);
        this.semanticTokenRegistry.registerTokenModifier('async', (0, ide_core_browser_1.localize)('async', 'Style to use for symbols that are async.'), undefined);
        this.semanticTokenRegistry.registerTokenModifier('readonly', (0, ide_core_browser_1.localize)('readonly', 'Style to use for symbols that are readonly.'), undefined);
    }
    registerDefaultTokenType() {
        this.doRegisterTokenType('comment', (0, ide_core_browser_1.localize)('comment', 'Style for comments.'), [['comment']]);
        this.doRegisterTokenType('string', (0, ide_core_browser_1.localize)('string', 'Style for strings.'), [['string']]);
        this.doRegisterTokenType('keyword', (0, ide_core_browser_1.localize)('keyword', 'Style for keywords.'), [['keyword.control']]);
        this.doRegisterTokenType('number', (0, ide_core_browser_1.localize)('number', 'Style for numbers.'), [['constant.numeric']]);
        this.doRegisterTokenType('regexp', (0, ide_core_browser_1.localize)('regexp', 'Style for expressions.'), [['constant.regexp']]);
        this.doRegisterTokenType('operator', (0, ide_core_browser_1.localize)('operator', 'Style for operators.'), [['keyword.operator']]);
        this.doRegisterTokenType('namespace', (0, ide_core_browser_1.localize)('namespace', 'Style for namespaces.'), [['entity.name.namespace']]);
        this.doRegisterTokenType('type', (0, ide_core_browser_1.localize)('type', 'Style for types.'), [['entity.name.type'], ['support.type']]);
        this.doRegisterTokenType('struct', (0, ide_core_browser_1.localize)('struct', 'Style for structs.'), [['entity.name.type.struct']]);
        this.doRegisterTokenType('class', (0, ide_core_browser_1.localize)('class', 'Style for classes.'), [
            ['entity.name.type.class'],
            ['support.class'],
        ]);
        this.doRegisterTokenType('interface', (0, ide_core_browser_1.localize)('interface', 'Style for interfaces.'), [
            ['entity.name.type.interface'],
        ]);
        this.doRegisterTokenType('enum', (0, ide_core_browser_1.localize)('enum', 'Style for enums.'), [['entity.name.type.enum']]);
        this.doRegisterTokenType('typeParameter', (0, ide_core_browser_1.localize)('typeParameter', 'Style for type parameters.'), [
            ['entity.name.type.parameter'],
        ]);
        this.doRegisterTokenType('function', (0, ide_core_browser_1.localize)('function', 'Style for functions'), [
            ['entity.name.function'],
            ['support.function'],
        ]);
        this.doRegisterTokenType('member', (0, ide_core_browser_1.localize)('member', 'Style for member functions'), [], 'method', 'Deprecated use `method` instead');
        this.doRegisterTokenType('method', (0, ide_core_browser_1.localize)('method', 'Style for method (member functions)'), [
            ['entity.name.function.member'],
            ['support.function'],
        ]);
        this.doRegisterTokenType('macro', (0, ide_core_browser_1.localize)('macro', 'Style for macros.'), [['entity.name.function.preprocessor']]);
        this.doRegisterTokenType('variable', (0, ide_core_browser_1.localize)('variable', 'Style for variables.'), [
            ['variable.other.readwrite'],
            ['entity.name.variable'],
        ]);
        this.doRegisterTokenType('parameter', (0, ide_core_browser_1.localize)('parameter', 'Style for parameters.'), [['variable.parameter']]);
        this.doRegisterTokenType('property', (0, ide_core_browser_1.localize)('property', 'Style for properties.'), [['variable.other.property']]);
        this.doRegisterTokenType('enumMember', (0, ide_core_browser_1.localize)('enumMember', 'Style for enum members.'), [
            ['variable.other.enummember'],
        ]);
        this.doRegisterTokenType('event', (0, ide_core_browser_1.localize)('event', 'Style for events.'), [['variable.other.event']]);
        this.doRegisterTokenType('label', (0, ide_core_browser_1.localize)('labels', 'Style for labels. '), undefined);
    }
    registerDefaultTokenStyles() {
        this.doRegisterTokenStyleDefault('variable.readonly', [['variable.other.constant']]);
        this.doRegisterTokenStyleDefault('property.readonly', [['variable.other.constant.property']]);
        this.doRegisterTokenStyleDefault('type.defaultLibrary', [['support.type']]);
        this.doRegisterTokenStyleDefault('class.defaultLibrary', [['support.class']]);
        this.doRegisterTokenStyleDefault('interface.defaultLibrary', [['support.class']]);
        this.doRegisterTokenStyleDefault('variable.defaultLibrary', [['support.variable'], ['support.other.variable']]);
        this.doRegisterTokenStyleDefault('variable.defaultLibrary.readonly', [['support.constant']]);
        this.doRegisterTokenStyleDefault('property.defaultLibrary', [['support.variable.property']]);
        this.doRegisterTokenStyleDefault('property.defaultLibrary.readonly', [['support.constant.property']]);
        this.doRegisterTokenStyleDefault('function.defaultLibrary', [['support.function']]);
        this.doRegisterTokenStyleDefault('member.defaultLibrary', [['support.function']]);
    }
    doRegisterTokenStyleDefault(selectorString, scopesToProbe) {
        try {
            const selector = this.semanticTokenRegistry.parseTokenSelector(selectorString);
            this.semanticTokenRegistry.registerTokenStyleDefault(selector, { scopesToProbe });
        }
        catch (e) {
            this.logger.error('Failed to register token style default', e);
        }
    }
    doRegisterTokenType(id, description, scopesToProbe = [], superType, deprecationMessage) {
        this.semanticTokenRegistry.registerTokenType(id, description, superType, deprecationMessage);
        if (scopesToProbe) {
            this.doRegisterTokenStyleDefault(id, scopesToProbe);
        }
        return id;
    }
    registerMenus(menus) {
        menus.registerMenuItem(next_1.MenuId.SettingsIconMenu, {
            command: exports.THEME_TOGGLE_COMMAND.id,
            group: '4_theme',
        });
        menus.registerMenuItem(next_1.MenuId.SettingsIconMenu, {
            command: exports.ICON_THEME_TOGGLE_COMMAND.id,
            group: '4_theme',
        });
        menus.registerMenuItem(next_1.MenuId.SettingsIconMenu, {
            command: exports.PRODUCT_ICON_THEME_TOGGLE_COMMAND.id,
            group: '4_theme',
        });
    }
    registerCommands(commands) {
        commands.registerCommand(exports.THEME_TOGGLE_COMMAND, {
            execute: async (options = {}) => {
                const { extensionId } = options;
                const getPickItems = (extensionId) => {
                    const themeInfos = this.themeService.getAvailableThemeInfos();
                    if (extensionId) {
                        const items = [];
                        let currentTheme;
                        for (const themeInfo of themeInfos) {
                            if (themeInfo.themeId === this.themeService.currentThemeId) {
                                currentTheme = themeInfo;
                            }
                            else if (themeInfo.extensionId === extensionId) {
                                items.push({
                                    label: (0, ide_core_browser_1.replaceLocalizePlaceholder)(themeInfo.name),
                                    value: themeInfo.themeId,
                                });
                            }
                        }
                        if (currentTheme) {
                            items.push({
                                label: (0, ide_core_browser_1.replaceLocalizePlaceholder)(currentTheme.name),
                                value: currentTheme === null || currentTheme === void 0 ? void 0 : currentTheme.themeId,
                                groupLabel: (0, ide_core_browser_1.localize)('theme.current', 'Current'),
                            });
                        }
                        return {
                            items,
                            defaultSelected: 0,
                        };
                    }
                    themeInfos.sort((a, b) => common_1.BuiltinThemeComparator[a.base] - common_1.BuiltinThemeComparator[b.base]);
                    let prevBase;
                    const items = themeInfos.map((themeInfo) => {
                        if (prevBase !== themeInfo.base && !(prevBase === null || prevBase === void 0 ? void 0 : prevBase.startsWith('hc'))) {
                            prevBase = themeInfo.base;
                            return {
                                label: (0, ide_core_browser_1.replaceLocalizePlaceholder)(themeInfo.name),
                                value: themeInfo.themeId,
                                groupLabel: (0, ide_core_browser_1.localize)((0, common_1.getThemeTypeName)(prevBase)),
                            };
                        }
                        return {
                            label: (0, ide_core_browser_1.replaceLocalizePlaceholder)(themeInfo.name),
                            value: themeInfo.themeId,
                        };
                    });
                    const defaultSelected = items.findIndex((opt) => opt.value === this.themeService.currentThemeId);
                    return {
                        items,
                        defaultSelected,
                    };
                };
                const { items, defaultSelected } = getPickItems(extensionId);
                const prevThemeId = this.themeService.currentThemeId;
                const themeId = await this.showPickWithPreview(items, {
                    selectIndex: (lookFor) => (lookFor ? -1 : defaultSelected),
                    placeholder: (0, ide_core_browser_1.localize)('theme.quickopen.plh'),
                }, (value) => {
                    this.updateTopPreference('general.theme', value);
                });
                if (themeId && themeId === this.themeService.currentThemeId) {
                    return;
                }
                await this.updateTopPreference('general.theme', themeId || prevThemeId);
            },
        });
        commands.registerCommand(exports.ICON_THEME_TOGGLE_COMMAND, {
            execute: async (options = {}) => {
                const { extensionId } = options;
                const getPickItems = (extensionId) => {
                    const themeInfos = this.iconService.getAvailableThemeInfos();
                    if (extensionId) {
                        const items = [];
                        let currentTheme;
                        for (const themeInfo of themeInfos) {
                            if (themeInfo.themeId === this.iconService.currentThemeId) {
                                currentTheme = themeInfo;
                            }
                            else if (themeInfo.extensionId === extensionId) {
                                items.push({
                                    label: themeInfo.name,
                                    value: themeInfo.themeId,
                                });
                            }
                        }
                        if (currentTheme) {
                            items.push({
                                label: currentTheme.name,
                                value: currentTheme.themeId,
                                groupLabel: (0, ide_core_browser_1.localize)('theme.current', 'Current'),
                            });
                        }
                        return {
                            items,
                            defaultSelected: 0,
                        };
                    }
                    const items = themeInfos.map((themeInfo) => ({
                        label: themeInfo.name,
                        value: themeInfo.themeId,
                    }));
                    const defaultSelected = items.findIndex((opt) => opt.value === this.iconService.currentThemeId);
                    return {
                        items,
                        defaultSelected,
                    };
                };
                const { items, defaultSelected } = getPickItems(extensionId);
                const prevThemeId = this.iconService.currentThemeId;
                const themeId = await this.showPickWithPreview(items, {
                    selectIndex: (lookFor) => (lookFor ? -1 : defaultSelected),
                    placeholder: (0, ide_core_browser_1.localize)('theme.icon.quickopen.plh'),
                }, (value) => {
                    this.updateTopPreference("general.icon" /* GeneralSettingsId.Icon */, value);
                });
                if (themeId) {
                    await this.updateTopPreference("general.icon" /* GeneralSettingsId.Icon */, themeId);
                }
                else {
                    await this.updateTopPreference("general.icon" /* GeneralSettingsId.Icon */, prevThemeId);
                }
            },
        });
        commands.registerCommand(exports.PRODUCT_ICON_THEME_TOGGLE_COMMAND, {
            execute: async () => {
                const productIcons = this.productIconService.getAvailableThemeInfos();
                const items = productIcons.map((productIcon) => ({
                    label: productIcon.name,
                    value: productIcon.themeId,
                }));
                const defaultSelected = items.findIndex((opt) => opt.value === this.productIconService.currentThemeId);
                const prevThemeId = this.productIconService.currentThemeId;
                const themeId = await this.showPickWithPreview(items, {
                    selectIndex: () => defaultSelected,
                    placeholder: (0, ide_core_browser_1.localize)('theme.productIcon.quickopen.plh'),
                }, (value) => {
                    this.updateTopPreference("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */, value);
                });
                if (themeId) {
                    await this.updateTopPreference("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */, themeId);
                }
                else {
                    await this.updateTopPreference("general.productIconTheme" /* GeneralSettingsId.ProductIconTheme */, prevThemeId);
                }
            },
        });
    }
    async updateTopPreference(key, value) {
        const effectiveScope = this.preferenceService.resolve(key).scope;
        // 最小就更新 User 的值
        if (typeof effectiveScope === 'undefined' || effectiveScope <= ide_core_browser_1.PreferenceScope.User) {
            await this.preferenceService.set(key, value, ide_core_browser_1.PreferenceScope.User);
        }
        else {
            await this.preferenceService.set(key, value, effectiveScope);
        }
    }
    showPickWithPreview(pickItems, options, onFocusChange) {
        return new Promise((resolve) => {
            const items = [];
            pickItems.forEach((item, index) => {
                const baseOption = {
                    label: item.label,
                    run: (mode) => {
                        if (mode === ide_core_browser_1.Mode.PREVIEW) {
                            onFocusChange(item.value);
                            return true;
                        }
                        if (mode === ide_core_browser_1.Mode.OPEN) {
                            resolve(item.value);
                            return true;
                        }
                        return false;
                    },
                };
                items.push(new ide_core_browser_1.QuickOpenItem(Object.assign(baseOption, { groupLabel: item.groupLabel, showBorder: !!item.groupLabel && index !== 0 })));
            });
            this.quickOpenService.open({
                onType: (_, acceptor) => acceptor(items),
            }, Object.assign({ onClose: () => resolve(undefined), fuzzyMatchLabel: true, showItemsWithoutHighlight: false }, options));
        });
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IThemeService),
    tslib_1.__metadata("design:type", Object)
], ThemeContribution.prototype, "themeService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IIconService),
    tslib_1.__metadata("design:type", Object)
], ThemeContribution.prototype, "iconService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IProductIconService),
    tslib_1.__metadata("design:type", Object)
], ThemeContribution.prototype, "productIconService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.QuickOpenService),
    tslib_1.__metadata("design:type", Object)
], ThemeContribution.prototype, "quickOpenService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.PreferenceService),
    tslib_1.__metadata("design:type", Object)
], ThemeContribution.prototype, "preferenceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(semantic_tokens_registry_1.ISemanticTokenRegistry),
    tslib_1.__metadata("design:type", Object)
], ThemeContribution.prototype, "semanticTokenRegistry", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.ILogger),
    tslib_1.__metadata("design:type", Object)
], ThemeContribution.prototype, "logger", void 0);
ThemeContribution = tslib_1.__decorate([
    (0, ide_core_browser_1.Domain)(next_1.MenuContribution, ide_core_browser_1.CommandContribution, ide_core_browser_1.ClientAppContribution)
], ThemeContribution);
exports.ThemeContribution = ThemeContribution;
//# sourceMappingURL=theme.contribution.js.map