"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getThemeId = exports.themeColorFromId = exports.getThemeType = exports.getThemeTypeSelector = exports.getBuiltinRules = exports.HIGH_CONTRAST_LIGHT = exports.HIGH_CONTRAST_DARK = exports.LIGHT = exports.DARK = exports.HC_LIGHT_THEME_NAME = exports.HC_BLACK_THEME_NAME = exports.VS_DARK_THEME_NAME = exports.VS_LIGHT_THEME_NAME = exports.BuiltinThemeComparator = exports.getThemeTypeName = exports.ColorScheme = exports.IThemeStore = exports.IThemeData = exports.IconShape = exports.IconType = exports.IProductIconService = exports.IThemeService = exports.IIconService = exports.colorIdPattern = exports.PRODUCT_ICON_CODICON_STYLE_ID = exports.PRODUCT_ICON_STYLE_ID = exports.DEFAULT_PRODUCT_ICON_THEME_LABEL = exports.DEFAULT_PRODUCT_ICON_THEME_ID = exports.DEFAULT_THEME_ID = exports.ThemeServicePath = void 0;
const default_themes_1 = require("./default-themes");
exports.ThemeServicePath = 'themeServicePath';
exports.DEFAULT_THEME_ID = 'ide-dark';
exports.DEFAULT_PRODUCT_ICON_THEME_ID = 'opensumi-icons';
exports.DEFAULT_PRODUCT_ICON_THEME_LABEL = 'OpenSumi Icons';
exports.PRODUCT_ICON_STYLE_ID = 'product-icon-style';
// codiconStyles 为 monaco 内置样式表
exports.PRODUCT_ICON_CODICON_STYLE_ID = 'codiconStyles';
// from vscode
exports.colorIdPattern = '^\\w+[.\\w+]*$';
exports.IIconService = Symbol('IIconTheme');
exports.IThemeService = Symbol('IThemeService');
exports.IProductIconService = Symbol('IProductIconService');
var IconType;
(function (IconType) {
    IconType["Mask"] = "mask";
    IconType["Background"] = "background";
    IconType["Base64"] = "base64";
})(IconType = exports.IconType || (exports.IconType = {}));
var IconShape;
(function (IconShape) {
    IconShape[IconShape["Circle"] = 0] = "Circle";
    IconShape[IconShape["Square"] = 1] = "Square";
})(IconShape = exports.IconShape || (exports.IconShape = {}));
exports.IThemeData = Symbol('IThemeData');
exports.IThemeStore = Symbol('IThemeStore');
/**
 * Color scheme used by the OS and by color themes.
 */
var ColorScheme;
(function (ColorScheme) {
    ColorScheme["DARK"] = "dark";
    ColorScheme["LIGHT"] = "light";
    ColorScheme["HIGH_CONTRAST_DARK"] = "hcDark";
    ColorScheme["HIGH_CONTRAST_LIGHT"] = "hcLight";
})(ColorScheme = exports.ColorScheme || (exports.ColorScheme = {}));
function getThemeTypeName(base) {
    const map = {
        vs: 'theme.base.vs',
        'vs-dark': 'theme.base.vs-dark',
        'hc-black': 'theme.base.hc',
        'hc-light': 'theme.base.hc',
    };
    return map[base];
}
exports.getThemeTypeName = getThemeTypeName;
var BuiltinThemeComparator;
(function (BuiltinThemeComparator) {
    BuiltinThemeComparator[BuiltinThemeComparator["vs"] = 0] = "vs";
    BuiltinThemeComparator[BuiltinThemeComparator["vs-dark"] = 1] = "vs-dark";
    BuiltinThemeComparator[BuiltinThemeComparator["hc-black"] = 2] = "hc-black";
    BuiltinThemeComparator[BuiltinThemeComparator["hc-light"] = 3] = "hc-light";
})(BuiltinThemeComparator = exports.BuiltinThemeComparator || (exports.BuiltinThemeComparator = {}));
exports.VS_LIGHT_THEME_NAME = 'vs';
exports.VS_DARK_THEME_NAME = 'vs-dark';
exports.HC_BLACK_THEME_NAME = 'hc-black';
exports.HC_LIGHT_THEME_NAME = 'hc-light';
// base themes
exports.DARK = 'dark';
exports.LIGHT = 'light';
exports.HIGH_CONTRAST_DARK = 'hcDark';
exports.HIGH_CONTRAST_LIGHT = 'hcLight';
function getBuiltinRules(builtinTheme) {
    switch (builtinTheme) {
        case exports.VS_LIGHT_THEME_NAME:
            return default_themes_1.vs;
        case exports.VS_DARK_THEME_NAME:
            return default_themes_1.vs_dark;
        case exports.HC_BLACK_THEME_NAME:
            return default_themes_1.hc_black;
        case exports.HC_LIGHT_THEME_NAME:
            return default_themes_1.hc_light;
    }
}
exports.getBuiltinRules = getBuiltinRules;
function getThemeTypeSelector(type) {
    switch (type) {
        case exports.DARK:
            return 'vs-dark';
        case exports.HIGH_CONTRAST_DARK:
            return 'hc-black';
        case exports.HIGH_CONTRAST_LIGHT:
            return 'hc-light';
        default:
            return 'vs';
    }
}
exports.getThemeTypeSelector = getThemeTypeSelector;
function getThemeType(base) {
    switch (base) {
        case exports.VS_LIGHT_THEME_NAME:
            return exports.LIGHT;
        case exports.VS_DARK_THEME_NAME:
            return exports.DARK;
        case exports.HC_BLACK_THEME_NAME:
            return exports.HIGH_CONTRAST_DARK;
        case exports.HC_LIGHT_THEME_NAME:
            return exports.HIGH_CONTRAST_LIGHT;
    }
}
exports.getThemeType = getThemeType;
function themeColorFromId(id) {
    return { id };
}
exports.themeColorFromId = themeColorFromId;
function getThemeId(contribution) {
    if (contribution.id) {
        return contribution.id;
    }
    return `${contribution.uiTheme || 'vs-dark'} ${toCSSSelector('vscode-theme', contribution.path)}`;
}
exports.getThemeId = getThemeId;
function toCSSSelector(extensionId, path) {
    if (path.indexOf('./') === 0) {
        path = path.substring(2);
    }
    let str = `${extensionId}-${path}`;
    // remove all characters that are not allowed in css
    str = str.replace(/[^_\-a-zA-Z0-9]/g, '-');
    if (str.charAt(0).match(/[0-9\-]/)) {
        str = '_' + str;
    }
    return str;
}
//# sourceMappingURL=theme.service.js.map